@@ -86,6 +86,10 @@ class VariableList2D:
     def y_name(self):
         return f"Y {self.name}"
 
+    @property
+    def magnitude(self):
+        return np.linalg.norm(self.value)
+
 
 def scatter_2d(x_list, y_list):
     if isinstance(x_list, VariableList):
